#
# spec file for package pantheon-calendar
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 0
%define         appid io.elementary.calendar
Name:           pantheon-calendar
Version:        8.0.0
Release:        1.3
Summary:        Maya Calendar for the Pantheon Desktop
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/calendar
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(champlain-0.12)
BuildRequires:  pkgconfig(champlain-gtk-0.12)
BuildRequires:  pkgconfig(clutter-1.0)
BuildRequires:  pkgconfig(folks)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(geocode-glib-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(granite) >= 6.2.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.11.6
BuildRequires:  pkgconfig(libedataserver-1.2)
BuildRequires:  pkgconfig(libgeoclue-2.0)
BuildRequires:  pkgconfig(libhandy-1) >= 0.90.0
BuildRequires:  pkgconfig(libical)
BuildRequires:  pkgconfig(libportal)
BuildRequires:  pkgconfig(libportal-gtk3)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(vapigen) >= 0.40.4
Provides:       elementary-calendar = %{version}
Obsoletes:      elementary-calendar < %{version}

%description
A slim, lightweight Granite calendar app written in Vala, designed for
the Pantheon Desktop where it is known simply as Calendar.

Also looks and works great on other GTK desktops.

%package -n     libelementary-calendar%{sover}
Summary:        The calendar for the Pantheon Desktop

%description -n libelementary-calendar%{sover}
A slim, lightweight Granite calendar app written in Vala, designed for
Elementary OS where it is known simply as Calendar.

%package        plugins
Summary:        A collection of plugins for %{name}
Requires:       %{name} = %{version}

%description    plugins
Calendar for the Pantheon Desktop.

This package contains a collection of plugins: CalDAV, Google and etc.

%package        devel
Summary:        Development files for lib%{name}
Requires:       libelementary-calendar%{sover} = %{version}

%description    devel
This subpackage contains libraries and header files for developing
applications

%lang_package

%prep
%autosetup -n calendar-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}/%{_datadir}

%ldconfig_scriptlets -n libelementary-calendar%{sover}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/vala/vapi/elementary-calendar.{deps,vapi}
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files -n libelementary-calendar%{sover}
%{_libdir}/libelementary-calendar.so.*

%files plugins
%dir %{_libdir}/{%{appid},%{appid}/plugins}
%{_libdir}/%{appid}/plugins/*

%files devel
%{_includedir}/elementary-calendar
%{_libdir}/libelementary-calendar.so
%{_libdir}/pkgconfig/elementary-calendar.pc

%files lang -f %{appid}.lang

%changelog
* Fri Nov  1 2024 Richard Rahl <rrahl0@opensuse.org>
- rename to pantheon-calendar
- remove %%suse_update_desktop_file, as it's deprecated
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- enable leap by using datadir/icons
* Sun Aug 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * New flatter design
  * Updated translations
- update to 7.0.0:
  * Add support for Evolution Data Server 3.46
  * Fix meson warnings
  * Require newer meson and fix deprecations
  * Metainfo Improvements
  * Application: Force use of portals
- update to 6.1.2:
  * Updated translations
- update to 6.1.1:
  * Updated app icon
  * Updated translations
- update to 6.1.0:
  * Ask for confirmation before deleting events
  * Follow email and web links in the event description with Control + Click
  * Disabled checkbox "Mark as default calendar" in calendar settings, if the calendar is read-only
  * Removed no longer needed sandbox permission for accounts service
  * Fixed potential memory leak
- update to 6.0.3:
  * Ensure Calendar runs in the background on startup
  * Fix memory leak when getting timezone information
  * Reliably read Windows-style timezones
  * Updated translations
- update to 6.0.2:
  * Fix notification icons in the notification indicator
  * Fix an issue where event timezones were overwritten
  * Ensure Calendar is launched when notifications are clicked
  * Updated translations
- update to 6.0.1:
  * Fix broken calendar color with some online providers
  * Fix an issue with some all-day events
  * Updated translations
- update to 6.0.0:
  * Import ICS files from the gear menu
  * Support the dark style
  * Properly show events on the last day of the month
  * Fix end times for all-day events
  * Notify for all alarms on an event
  * Improved offline support
  * New colorful avatar fallbacks
  * Include "film" as an event icon keyword
  * Add Mint and Bubblegum to calendar color chooser
  * Link to Online Accounts settings in the gear menu
  * Performance improvements
  * Updated translations
- update to 5.1.1:
  * Fix an issue where new events could appear twice in Calendar
  * "Mark as default calendar" box is now correctly checked when editing a calendar
  * Updated translations
- update to 5.1.0:
  * Allow modification of recurring events
  * Improve handling of week start day
  * Fix timezone errors with all-day events
  * Don't resize the sidebar when resizing the window
  * Updated translations
- update to 5.0.6:
  * Fix issues with time zones not being recognized
  * Updated translations
- update to 5.0.5:
  * Fix several issues with adding and removing monthly recurring events
  * Updated translations
- update to 5.0.4:
  * Correctly save event reminders
  * Ellipsize event participant details if necessary
  * Fix unwanted rescheduling when editing event title
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Wed Dec 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.0.3:
  * Utils: fix several crashes with event processing (#461)
  * Add Lint to CI (#434)
  * Set color as fg_color for cell class (#458)
  * Reset AgendaView items when parameters change (#456)
  * Travis: downgrade node to 10
  * Add Release to Actions (#450)
  * AppData: Update release information (#448)
  * Add specific CSS files per class (#443)
  * Utils: Remove unused is_day_in_range (#442)
  * Use GLib.DateWeekday (#441)
  * Use the next whole hour for the default time (#209)
  * Lint source files (#435)
  * Delete CODE_OF_CONDUCT.md
  * Delete FUNDING.yml
  * Add compatibility with libecal-1.2 and libical-glib (#431)
  * Fix libical.vapi
  * More alignments with libical-glib and libecal-2.0
  * Construct new event dialog at idle (#425)
  * Improve the compatibility with libecal-2.0 and libical-glib
    (#430)
  * Bring more compatibility with libecal-2.0 and libical-glib
    (#429)
  * Use EDS to compute recursive events (#426)
  * Merge branch 'origin/master' into Weblate.
  * libical: rename ICal.DurationType into ICal.Duration
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.0:
  * ContractorButtonWithMenu: Use FileChooserNative (#379)
  * Merge branch 'origin/master' into Weblate
  * Daemon: Use calendar icon in notifications (#378)
  * Move languages format from core to src (#374)
  * README: Add libgeoclue dep (#377)
  * Daemon: fix indentation and whitespace (#376)
  * README: remove notify dep
  * Fix daemon to use GLib.Notification (#353)
  * Application: present import window when opening ICS files
    (#369)
  * Remove unused SourceManager (#373)
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 4.2.3:
  * Use Gtk.Application (#278)
  * Remove cairo draws (#276)
  * Merge branch 'origin/master' into Weblate
  * Fix Location Panel Initialization (#271)
  * Draw week label border with CSS (#273)
  * Add padding to weeknumber labels (#270)
  * travis: update to latest Houston (#272)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 4.2.2:
  * Merge branch 'origin/master' into Weblate
  * Use elipsis instead of three dots (#265)
  * Install daemon to libexec (#264)
  * Eliminate Gtk warning about :focused (#259)
- Switch to meson
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Drop maya-calendar-drop-obsolete-gconf2.patch
* Sat Jul  7 2018 bjorn.lie@gmail.com
- Add maya-calendar-drop-obsolete-gconf2.patch: Drop obsolete
  gconf-2.0 dependency, patch sent upstream.
- Following the above drop pkgconfig(gconf-2.0) BuildRequires: No
  longer needed, nor used.
* Sat Jun 23 2018 avvissu@yandex.by
- Update to 0.4.2.1:
  * Merge remote-tracking branch 'origin/master'
  * Utils: Update location of datetime indicator setting (#243)
* Sat Jun  9 2018 avvissu@yandex.by
- Update to 0.4.2:
  * Rename files to follow RDNN naming convention (#226)
  * Rename pc.cmake to pc.in
  * Use build variables in appdata
  * Clean up whitespace
  * Remove unused dist and distcheck
  * Don't append nonexistent module path
  * Remove unused build variables
  * Add EXEC_NAME build variable
  * Rename config.vala.cmake to config.vala.in
* Fri Jun  8 2018 avvissu@yandex.by
- Rename to elementary-calendar
- Drop maya-calendar-0.4.1-vapi.patch (fixed)
- Add a new package with plugins
- Update strings to search icon files
- Fix: Icon will not found when changing the lang settings
- Remove obsolete macros
- Spec file cleanup
* Mon Apr 23 2018 avvissu@yandex.by
- Fix build with vala >= 0.40.4 (add maya-calendar-0.4.1-vapi.patch)
* Sat Dec  2 2017 avvissu@yandex.by
- Update to 0.4.1:
  * Require Granite >= 0.5
  * Style calendar colours using css (#200)
  * Correct dekstop names for make pot (#203)
  * Store local calendar edits (#202)
  * Fallback to char wrapping if word is too long to wrap (#199)
  * Update version information (#197)
  * Add debug option to app_options (#190)
  * Use relative date format for same day notifications (#193)
  * Remove fields for deprecated about dialog (#192)
  * Correctly generate date ranges for repeat events (#183)
  * Add missing releases to appdata (#188)
  * Handle null dtends correctly (#184)
  * Correctly import ics files (#185)
  * Grab focus on event title when creating event (#146)
  * Correct selecting days in other months (#175)
  * Show event repeats in agenda correctly (#182)
  * Allow right clicking EventButtons (#178)
  * Allow right clicking week labels (#173)
  * Load non-standard ports when editing (#176)
  * Remove email notifications (#179)
  * Rewrite MayaToolbar as HeaderBar (#163)
  * Update EventButtons directly (#174)
  * Sort events on Grid (#171)
  * Follow week setting in System Settings (#172)
  * Implement control q accel with simpleaction (#158)
- Update homepage
- Switch from bzr to git
- Spec file cleanup
* Tue Jul 11 2017 bwiedemann@suse.com
- Sort file lists to always install the same .svg size
  to fix build-compare (boo#1041090)
* Sat Sep 10 2016 mailaender@opensuse.org
- Update to version 0.4.0.2
- Drop maya-0.3.1.1-eds-3.16.patch
* Mon Aug 22 2016 avvissu@yandex.by
- Fix: icon file not installed
- Spec file cleanup
* Sat Feb 27 2016 mailaender@opensuse.org
- add maya-0.3.1.1-eds-3.16.patch
* Sat Jun 20 2015 mailaender@opensuse.org
- update to version 0.3.1.1
* Sun May 10 2015 mailaender@opensuse.org
- update to version 0.3.1
  * requires vala 0.26 (lp#1455536)
* Sun Jun 15 2014 mailaender@opensuse.org
- initial packaging (version 0.3) for build.opensuse.org
